﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.UltraChart.Resources.Appearance;
using Infragistics.UltraChart.Shared.Styles;
using Infragistics.UltraChart.Core.Layers;
using Infragistics.UltraChart.Core.Primitives;
using Infragistics.UltraChart.Core;
using System.Diagnostics;
using System.Collections;

namespace WC_CompChartDifferentDataSources
{
    public partial class Form1 : Form
    {
        CustomTooltips labels = new CustomTooltips();
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            this.ultraChart1.ChartType = ChartType.Composite;

            Hashtable labelHash = new Hashtable();
            labelHash.Add("TOOLTIPS", labels);
            ultraChart1.LabelHash = labelHash;
            ultraChart1.Tooltips.FormatString = "<TOOLTIPS>";

            ChartArea histogramArea = new ChartArea();
            ChartArea lineArea = new ChartArea();

            this.ultraChart1.CompositeChart.ChartAreas.Add(histogramArea);
            this.ultraChart1.CompositeChart.ChartAreas.Add(lineArea);

            AxisItem axisYhistogram = new AxisItem();
            axisYhistogram.Extent = 50;
            axisYhistogram.DataType = AxisDataType.Numeric;
            axisYhistogram.Labels.ItemFormatString = "<DATA_VALUE:##.##>";
            axisYhistogram.OrientationType = AxisNumber.Y_Axis;
            axisYhistogram.LineColor = Color.Silver;
            histogramArea.Axes.Add(axisYhistogram);

            AxisItem axisXhistogram = new AxisItem();
            axisXhistogram.Extent = 50;
            axisXhistogram.DataType = AxisDataType.String;
            axisXhistogram.OrientationType = AxisNumber.X_Axis;
            axisXhistogram.Labels.SeriesLabels.Orientation = TextOrientation.Custom;
            axisXhistogram.Labels.SeriesLabels.OrientationAngle = 312;
            axisXhistogram.SetLabelAxisType = SetLabelAxisType.GroupBySeries;
            axisXhistogram.LineColor = Color.Silver;
        
            histogramArea.Axes.Add(axisXhistogram);

            AxisItem axisYnormalDistribution = new AxisItem();
            axisYnormalDistribution.Extent = 50;
            axisYnormalDistribution.DataType = AxisDataType.Numeric;
            axisYnormalDistribution.Labels.ItemFormatString = "<DATA_VALUE:##.##>";
            axisYnormalDistribution.OrientationType = AxisNumber.Y_Axis;
            axisYnormalDistribution.Visible = false;
            axisYnormalDistribution.LineColor = Color.Silver;
            lineArea.Axes.Add(axisYnormalDistribution);

            AxisItem axisXnormalDistribution = new AxisItem();
            axisXnormalDistribution.Extent = 50;
            axisXnormalDistribution.DataType = AxisDataType.String;
            axisXnormalDistribution.Labels.Orientation = TextOrientation.VerticalLeftFacing;
            axisXnormalDistribution.Labels.ItemFormatString = "<ITEM_LABEL>";
            axisXnormalDistribution.Labels.Visible = false;
            axisXnormalDistribution.OrientationType = AxisNumber.X_Axis;
            axisXnormalDistribution.SetLabelAxisType = SetLabelAxisType.ContinuousData;
            axisXnormalDistribution.LineColor = Color.Silver;
            lineArea.Axes.Add(axisXnormalDistribution);

            ChartLayerAppearance myColumnLayer = new ChartLayerAppearance();
            myColumnLayer.ChartType = ChartType.ColumnChart;
            myColumnLayer.SwapRowsAndColumns = true;
            myColumnLayer.ChartArea = histogramArea;

            ChartLayerAppearance myLineLayer = new ChartLayerAppearance();
            myLineLayer.ChartType = ChartType.LineChart;
            myLineLayer.ChartArea = lineArea;

            NumericSeries histogramSeries = new NumericSeries();
            histogramSeries.DataBind(GetHistogramData(), "Value", "Month");
            histogramSeries.PEs.Add(new PaintElement(Color.LightSlateGray, Color.LightSlateGray, GradientStyle.None));
            myColumnLayer.Series.Add(histogramSeries);
            ultraChart1.CompositeChart.Series.Add(histogramSeries);

            NumericSeries normalDestributionSeries = new NumericSeries();
            normalDestributionSeries.DataBind(GetNormalDestributionData(), "Cumm Plane", "Month");
            normalDestributionSeries.PEs.Add(new PaintElement(Color.Red));
            myLineLayer.Series.Add(normalDestributionSeries);
            ultraChart1.CompositeChart.Series.Add(normalDestributionSeries);

            ColumnChartAppearance appearance = new ColumnChartAppearance();
            appearance.SeriesSpacing = 0;
            myColumnLayer.ChartTypeAppearance = appearance;

            myColumnLayer.AxisX = axisXhistogram;
            myColumnLayer.AxisY = axisYhistogram;
           
            this.ultraChart1.CompositeChart.ChartLayers.Add(myColumnLayer);

            myLineLayer.AxisX = axisXnormalDistribution;
            myLineLayer.AxisY = axisYnormalDistribution;
            this.ultraChart1.CompositeChart.ChartLayers.Add(myLineLayer);

        }

        private DataTable GetNormalDestributionData()
        {
            DataTable lineDt = new DataTable();
            lineDt.Columns.Add("Month");
            lineDt.Columns.Add("Cumm Plane", typeof(decimal));

            lineDt.Rows.Add("Apr-10", 1.039381);
            lineDt.Rows.Add("May-10", 1.531703);
            lineDt.Rows.Add("Jun-10", 2.166947);
            lineDt.Rows.Add("Jul-10", 2.943036);
            lineDt.Rows.Add("Aug-10", 3.837218);
            lineDt.Rows.Add("Sep-10", 4.802984);
            lineDt.Rows.Add("Oct-10", 5.771378);
            lineDt.Rows.Add("Nov-10", 6.657660);
            lineDt.Rows.Add("Dec-10", 7.372884);
            lineDt.Rows.Add("Jan-11", 7.838389);
            lineDt.Rows.Add("Feb-11", 8.000000);
            lineDt.Rows.Add("Mar-11", 7.838389);
            lineDt.Rows.Add("Apr-11", 7.372884);
            lineDt.Rows.Add("May-11", 6.657660);
            lineDt.Rows.Add("Jun-11", 5.771378);
            lineDt.Rows.Add("Jul-11", 4.802984);
            lineDt.Rows.Add("Aug-11", 3.837218);
            lineDt.Rows.Add("Sep-11", 2.943036);
            lineDt.Rows.Add("Nov-11", 2.166947);
            lineDt.Rows.Add("Dec-11", 1.531703);

            return lineDt;
        }

        private DataTable GetHistogramData()
        {
            DataTable lineDt = new DataTable();
            lineDt.Columns.Add("Month");
            lineDt.Columns.Add("Value", typeof(decimal));

            lineDt.Rows.Add("Apr-10", 1.039381);
            lineDt.Rows.Add("May-10", 1.531703);
            lineDt.Rows.Add("Jun-10", 2.166947);
            lineDt.Rows.Add("Jul-10", 2.943036);
            lineDt.Rows.Add("Aug-10", 3.837218);
            lineDt.Rows.Add("Sep-10", 4.802984);
            lineDt.Rows.Add("Oct-10", 5.771378);
            lineDt.Rows.Add("Nov-10", 6.657660);
            lineDt.Rows.Add("Dec-10", 7.372884);

            return lineDt;

        }

        private void ultraChart1_FillSceneGraph(object sender, Infragistics.UltraChart.Shared.Events.FillSceneGraphEventArgs e)
        {
            var textPrims = e.SceneGraph.OfType<Text>();

            foreach (var text in textPrims)
            {
                text.Caps = PCaps.HitTest | PCaps.Tooltip;
               
            }
        }
        private void ultraChart1_MouseMove(object sender, MouseEventArgs e)
        {
            var layers = ultraChart1.CompositeChart.ChartLayers;
            foreach (ChartLayerAppearance layer in layers)
	        {
                bool success = false;
                if (layer.ChartLayer != null)
                {
                    var text = layer.ChartLayer.ChartCore.
                        GetChartPrimitiveFromPoint(e.Location) as Text;
                    if (text != null)
                    {
                        labels.Tooltip = text.GetTextString();
                        success = true;
                    }
                }
                if (!success)
                {
                    labels.Tooltip = String.Empty;
                }
                
	        }
        }

    }
}
